@@ -595,14 +595,14 @@ static int datetime_set_size(XfcePanelPlugin *plugin,
 static void datetime_read_rc_file(XfcePanelPlugin *plugin, t_datetime *dt)
 {
   gchar *file;
-  XfceRc *rc;
+  XfceRc *rc = NULL;
   t_layout layout;
   const gchar *date_font, *time_font, *date_format, *time_format;
 
   /* load defaults */
   layout = LAYOUT_DATE_TIME;
   date_font = "Bitstream Vera Sans 8";
-  time_font = "Bitstream Vera Sans 10";
+  time_font = "Bitstream Vera Sans 8";
   date_format = "%Y-%m-%d";
   time_format = "%H:%M";
 
@@ -619,8 +619,6 @@ static void datetime_read_rc_file(XfcePanelPlugin *plugin, t_datetime *dt)
       time_font   = xfce_rc_read_entry(rc, "time_font", time_font);
       date_format = xfce_rc_read_entry(rc, "date_format", date_format);
       time_format = xfce_rc_read_entry(rc, "time_format", time_format);
-
-      xfce_rc_close(rc);
     }
   }
 
@@ -629,6 +627,9 @@ static void datetime_read_rc_file(XfcePanelPlugin *plugin, t_datetime *dt)
   date_format = g_strdup(date_format);
   time_format = g_strdup(time_format);
 
+  if(rc != NULL)
+    xfce_rc_close(rc);
+
   /* set values in dt struct */
   datetime_apply_layout(dt, layout);
   datetime_apply_font(dt, date_font, time_font);
