@@ -2,6 +2,7 @@
  *
  *  Copyright (C) 2003 Choe Hwanjin(krisna@kldp.org)
  *  Copyright (c) 2006 Remco den Breeje <remco@sx.mine.nu>
+ *  Copyright (c) 2008 Diego Ongaro <ongardie@gmail.com>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU Library General Public License as published
@@ -21,6 +22,10 @@
 #ifndef DATETIME_H
 #define DATETIME_H
 
+#define I_CAN_HAS_BUGGY_TULTIPZ  0
+#define USE_GTK_TOOLTIP_API       (I_CAN_HAS_BUGGY_TULTIPZ && \
+                                   GTK_CHECK_VERSION(2,12,0))
+
 /* enums */
 enum {
   DATE = 0,
@@ -30,21 +35,25 @@ enum {
 /* typedefs */
 typedef enum
 {
-  LAYOUT_DATE = 0,
-  LAYOUT_TIME,
-  LAYOUT_DATE_TIME,
+  LAYOUT_DATE_TIME = 0,
   LAYOUT_TIME_DATE,
+  LAYOUT_DATE,
+  LAYOUT_TIME,
   LAYOUT_COUNT
 } t_layout;
 
 typedef struct {
   XfcePanelPlugin * plugin;
-  GtkWidget *eventbox;
-  GtkWidget *frame;
+  GtkWidget *button;
   GtkWidget *vbox;
   GtkWidget *date_label;
   GtkWidget *time_label;
+  guint update_interval;  /* time between updates in milliseconds */
   guint timeout_id;
+#if USE_GTK_TOOLTIP_API
+  guint tooltip_timeout_id;
+  gulong tooltip_handler_id;
+#endif
 
   /* settings */
   gchar *date_font;
@@ -54,9 +63,19 @@ typedef struct {
   t_layout layout;
 
   /* option widgets */
+  GtkWidget *date_frame;
+#if USE_GTK_TOOLTIP_API
+  GtkWidget *date_tooltip_label;
+#endif
+  GtkWidget *date_font_hbox;
   GtkWidget *date_font_selector;
   GtkWidget *date_format_combobox;
   GtkWidget *date_format_entry;
+  GtkWidget *time_frame;
+#if USE_GTK_TOOLTIP_API
+  GtkWidget *time_tooltip_label;
+#endif
+  GtkWidget *time_font_hbox;
   GtkWidget *time_font_selector;
   GtkWidget *time_format_combobox;
   GtkWidget *time_format_entry;
@@ -66,11 +85,11 @@ typedef struct {
 } t_datetime;
 
 gboolean
-datetime_update(gpointer data);
+datetime_update(t_datetime *datetime);
 
-gchar * 
+gchar *
 datetime_do_utf8strftime(
-    const char *format, 
+    const char *format,
     const struct tm *tm);
 
 void
@@ -83,8 +102,8 @@ datetime_apply_format(t_datetime *datetime,
     const gchar *date_format,
     const gchar *time_format);
 
-void 
-datetime_apply_layout(t_datetime *datetime, 
+void
+datetime_apply_layout(t_datetime *datetime,
     t_layout layout);
 
 void
